Stan Math Library: stan::is_var_or_arithmetic< T1, T2, T3, T4, T5, T6 > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Types | List of all members
stan::is_var_or_arithmetic< T1, T2, T3, T4, T5, T6 > Struct Template Reference

`#include <is_var_or_arithmetic.hpp>`

## Public Types
enum | { value }

## Detailed Description

### template<typename T1, typename T2 = double, typename T3 = double, typename T4 = double, typename T5 = double, typename T6 = double>
struct stan::is_var_or_arithmetic< T1, T2, T3, T4, T5, T6 >

Definition at line 16 of file is_var_or_arithmetic.hpp.

## Member Enumeration Documentation

template<typename T1 , typename T2 = double, typename T3 = double, typename T4 = double, typename T5 = double, typename T6 = double>

anonymous enum

Enumerator
value |

Definition at line 17 of file is_var_or_arithmetic.hpp.

The documentation for this struct was generated from the following file:

- stan/math/prim/scal/meta/is_var_or_arithmetic.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.